@@ -2,7 +2,7 @@
 ## PLot of STS sequence objects
 ## =============================
 
-plot.stslist <- function(x, tlim=NULL, sortv=NULL, 
+plot.stslist <- function(x, tlim=NULL, weighted=TRUE, sortv=NULL, 
 	cpal=NULL, missing.color=NULL, ylab=NULL, yaxis=TRUE, xaxis=TRUE, xtlab=NULL, cex.plot=1, ...) {
 
 	n <- nrow(x)
@@ -14,7 +14,10 @@ plot.stslist <- function(x, tlim=NULL, sortv=NULL,
 		xtlab <- colnames(x)
 
 	## Range 
-	if (is.null(tlim)) tlim <- 1:10
+	if (is.null(tlim)) {
+		if (n>=10) tlim <- 1:10
+		else tlim=1:n
+	}
 	else if (tlim[1]==0) 
 			tlim <- 1:n
 	else if (max(tlim) > n) 
@@ -42,16 +45,34 @@ plot.stslist <- function(x, tlim=NULL, sortv=NULL,
 		statl <- c(statl, nr)
 	}
 
-	if (is.null(ylab))
-		ylab <- paste("Seq. ", min(tlim)," to ",max(tlim), " (n=",n,")", sortlab, sep="")
-
+	## Storing the optional parameters in a list
 	olist <- list(...)
 
 	ssamp <- x[tlim,]
 	seqbar <- apply(ssamp, 1, seqgbar, statl=statl, seql=seql)
 
+	## WEIGHTS
+	## Weights
+	weights <- attr(x, "weights")
+
+	if (!weighted || is.null(weights)) {
+		weights <- rep(1.0, nrow(x))
+	}
+	## Also takes into account that in unweighted sequence objects created with 
+	## older TraMineR versions the weights attribute is a vector of 1
+	## instead of NULL  
+	if (all(weights==1)) 
+		weighted <- FALSE
+
+	if (weighted) {wlab <- "weighted "}
+	else {wlab <- NULL}
+
+	if (is.null(ylab))
+		ylab <- paste(length(tlim)," seq. ", "(", wlab,"n=",sum(weights),")", 
+			sortlab, sep="")
+
 	## The PLot
-	barplot(seqbar,col=cpal,
+	barplot(seqbar,col=cpal, width=weights,
 		ylab=ylab,
 		horiz=TRUE,
 		yaxt="n",
@@ -66,17 +87,29 @@ plot.stslist <- function(x, tlim=NULL, sortv=NULL,
 		# mgp=c(3,0.5,0), 
 		cex.axis=cex.plot)
 
+	## Plotting the y axis
 	if (is.null(yaxis) || yaxis) {
 		if ("space" %in% names(olist)) sp <- olist[["space"]]
 		else sp <- 0.2
 
-		y.lab.pos <- sp+0.5
+		idxmax <- length(tlim)
+		
+		if (!weighted) {
+			y.lab.pos <- sp+0.5
 
-		idxmax <- max(tlim)
+			if (idxmax>1) {
+				for (p in 2:idxmax) {
+					y.lab.pos <- c(y.lab.pos, (p-1)+((p-1)*sp)+(0.5+sp))
+				}
+			}
+		}
+		else {
+			y.lab.pos <- (weights[1]/2)+1
+			sep <- sp*mean(weights)
 
-		if (idxmax>1) {
-			for (p in 2:idxmax) {
-				y.lab.pos <- c(y.lab.pos, (p-1)+((p-1)*sp)+(0.5+sp))
+			if (idxmax>1) {
+				for (p in 2:idxmax)
+					y.lab.pos <- c(y.lab.pos, sum(weights[1:p])+(p*sep)-weights[p]/2)
 			}
 		}
 
