@@ -2,17 +2,22 @@
 ## Mean durations
 ## ==============
 
-seqmeant <- function(seqdata, weighted=TRUE) {
+seqmeant <- function(seqdata, weighted=TRUE, with.missing=FALSE) {
 
 	if (!inherits(seqdata,"stslist"))
 		stop("data is not a sequence object, use seqdef function to create one")
 
-	istatd <- suppressMessages(seqistatd(seqdata))
+	istatd <- suppressMessages(seqistatd(seqdata, with.missing=with.missing))
 
 	weights <- attr(seqdata, "weights")
 
 	if (!weighted || is.null(weights)) 
 		weights <- rep(1, nrow(seqdata))
+	## Also takes into account that in unweighted sequence objects created with 
+	## older TraMineR versions the weights attribute is a vector of 1
+	## instead of NULL  
+	if (all(weights==1)) 
+		weighted <- FALSE
 
 	mtime <- apply(istatd*weights,2,sum)
 
